@@ -1169,6 +1169,10 @@ def versions_from_file(filename):
 
     versions = {}
     try:
+        print("Trying to read: %s" % (filename))
+        with open(filename) as f:
+          print("Content:\n%s" % f.read())
+
         with open(filename) as f:
             for line in f.readlines():
                 mo = re.match("version_version = '([^']+)'", line)
@@ -1177,6 +1181,8 @@ def versions_from_file(filename):
                 mo = re.match("version_full = '([^']+)'", line)
                 if mo:
                     versions["full"] = mo.group(1)
+
+        print("Recovered version info:\n%s" % (versions,))
     except EnvironmentError:
         return {}
 
@@ -1227,6 +1233,8 @@ def get_versions(default=DEFAULT, verbose=False):
 
     # Try to get the version info from the VCS-specific replacement keywords.
 
+    verbose = True
+
     get_keywords_f = vcs_function(VCS, "get_keywords")
     versions_from_keywords_f = vcs_function(VCS, "versions_from_keywords")
     if get_keywords_f and versions_from_keywords_f:
